@@ -40,6 +40,7 @@ from pipenv.utils.requirementslib import (
 )
 
 from .constants import (
+    INSTALLABLE_EXTENSIONS,
     RELEVANT_PROJECT_FILES,
     REMOTE_SCHEMES,
     SCHEME_LIST,
@@ -363,16 +364,8 @@ def is_pinned_requirement(ireq):
 
 
 def is_editable_path(path):
-    not_editable = [".whl", ".zip", ".tar", ".tar.gz", ".tgz"]
-    if os.path.isfile(path):
-        return False
     if os.path.isdir(path):
         return True
-    if os.path.splitext(path)[1] in not_editable:
-        return False
-    for ext in not_editable:
-        if path.endswith(ext):
-            return False
     return False
 
 
@@ -521,37 +514,66 @@ def parse_pkginfo_file(content: str):
 
 
 def parse_setup_file(content):
+    # A dictionary to store variable names and their values
+    variables = {}
     try:
         tree = ast.parse(content)
         for node in ast.walk(tree):
-            if isinstance(node, ast.Call) and getattr(node.func, "id", "") == "setup":
-                for keyword in node.keywords:
-                    if keyword.arg == "name":
-                        if isinstance(keyword.value, ast.Str):
-                            return keyword.value.s
-                        elif sys.version_info < (3, 9) and isinstance(
-                            keyword.value, ast.Subscript
+            # Extract variable assignments and store them
+            if isinstance(node, ast.Assign):
+                for target in node.targets:
+                    if isinstance(target, ast.Name):
+                        if isinstance(node.value, ast.Str):  # for Python versions < 3.8
+                            variables[target.id] = node.value.s
+                        elif isinstance(node.value, ast.Constant) and isinstance(
+                            node.value.value, str
                         ):
-                            if (
-                                isinstance(keyword.value.value, ast.Name)
-                                and keyword.value.value.id == "about"
-                            ):
-                                if isinstance(
-                                    keyword.value.slice, ast.Index
-                                ) and isinstance(keyword.value.slice.value, ast.Str):
-                                    return keyword.value.slice.value.s
-                            return keyword.value.s
-                        elif sys.version_info >= (3, 9) and isinstance(
-                            keyword.value, ast.Subscript
-                        ):
-                            # If the name is a lookup in a dictionary, only handle the case where it's a static lookup
-                            if (
-                                isinstance(keyword.value.value, ast.Name)
-                                and isinstance(keyword.value.slice, ast.Str)
-                                and keyword.value.value.id == "about"
-                            ):
-                                return keyword.value.slice.s
+                            variables[target.id] = node.value.value
 
+            # Check function calls to extract the 'name' attribute from the setup function
+            if isinstance(node, ast.Call):
+                if (
+                    getattr(node.func, "id", "") == "setup"
+                    or isinstance(node.func, ast.Attribute)
+                    and node.func.attr == "setup"
+                ):
+                    for keyword in node.keywords:
+                        if keyword.arg == "name":
+                            # If it's a variable, retrieve its value
+                            if (
+                                isinstance(keyword.value, ast.Name)
+                                and keyword.value.id in variables
+                            ):
+                                return variables[keyword.value.id]
+                            # Otherwise, check if it's directly provided
+                            elif isinstance(keyword.value, ast.Str):
+                                return keyword.value.s
+                            elif isinstance(keyword.value, ast.Constant) and isinstance(
+                                keyword.value.value, str
+                            ):
+                                return keyword.value.value
+                            # Additional handling for Python versions and specific ways of defining the name
+                            elif sys.version_info < (3, 9) and isinstance(
+                                keyword.value, ast.Subscript
+                            ):
+                                if (
+                                    isinstance(keyword.value.value, ast.Name)
+                                    and keyword.value.value.id == "about"
+                                ):
+                                    if isinstance(
+                                        keyword.value.slice, ast.Index
+                                    ) and isinstance(keyword.value.slice.value, ast.Str):
+                                        return keyword.value.slice.value.s
+                                return keyword.value.s
+                            elif sys.version_info >= (3, 9) and isinstance(
+                                keyword.value, ast.Subscript
+                            ):
+                                if (
+                                    isinstance(keyword.value.value, ast.Name)
+                                    and isinstance(keyword.value.slice, ast.Str)
+                                    and keyword.value.value.id == "about"
+                                ):
+                                    return keyword.value.slice.s
     except ValueError:
         pass  # We will not exec unsafe code to determine the name pre-resolver
 
@@ -643,10 +665,29 @@ def determine_path_specifier(package: InstallRequirement):
         if package.link.scheme in ["http", "https"]:
             return package.link.url_without_fragment
         if package.link.scheme == "file":
+            abs_path = Path(package.link.file_path).resolve()
+            current_dir = Path.cwd()
+
             try:
-                return Path(package.link.file_path).relative_to(Path.cwd()).as_posix()
+                relative_path = abs_path.relative_to(current_dir)
+                return relative_path.as_posix()
             except ValueError:
-                return Path(package.link.file_path).as_posix()
+                # If the direct relative_to fails, manually compute the relative path
+                common_parts = 0
+                for part_a, part_b in zip(abs_path.parts, current_dir.parts):
+                    if part_a == part_b:
+                        common_parts += 1
+                    else:
+                        break
+
+                # Number of ".." needed are the extra parts in the current directory
+                # beyond the common parts
+                up_levels = [".."] * (len(current_dir.parts) - common_parts)
+                # The relative path is constructed by going up as needed and then
+                # appending the non-common parts of the absolute path
+                rel_parts = up_levels + list(abs_path.parts[common_parts:])
+                relative_path = Path(*rel_parts)
+                return relative_path.as_posix()
 
 
 def determine_vcs_specifier(package: InstallRequirement):
@@ -734,7 +775,9 @@ def determine_package_name(package: InstallRequirement):
             ".zip"
         ):
             req_name = find_package_name_from_zipfile(package.link.file_path)
-        elif package.link.file_path.endswith(".tar.gz"):
+        elif package.link.file_path.endswith(
+            ".tar.gz"
+        ) or package.link.file_path.endswith(".tar.bz2"):
             req_name = find_package_name_from_tarball(package.link.file_path)
         else:
             req_name = find_package_name_from_directory(package.link.file_path)
@@ -868,7 +911,7 @@ def expand_env_variables(line) -> AnyStr:
 
 
 def expansive_install_req_from_line(
-    name: str,
+    pip_line: str,
     comes_from: Optional[Union[str, InstallRequirement]] = None,
     *,
     use_pep517: Optional[bool] = None,
@@ -880,35 +923,43 @@ def expansive_install_req_from_line(
     user_supplied: bool = False,
     config_settings: Optional[Dict[str, Union[str, List[str]]]] = None,
     expand_env: bool = False,
-) -> InstallRequirement:
-    """Creates an InstallRequirement from a name, which might be a
-    requirement, directory containing 'setup.py', filename, or URL.
-
-    :param line_source: An optional string describing where the line is from,
-        for logging purposes in case of an error.
+) -> (InstallRequirement, str):
+    """Create an InstallRequirement from a pip-style requirement line.
+    InstallRequirement is a pip internal construct that represents an installable requirement,
+    and is used as an intermediary between the pip command and the resolver.
+    :param pip_line: A pip-style requirement line.
+    :param comes_from: The path to the requirements file the line was found in.
+    :param use_pep517: Whether to use PEP 517/518 when installing the
+        requirement.
+    :param isolated: Whether to isolate the requirements when installing them. (likely unused)
+    :param global_options: Extra global options to be used when installing the install req (likely unused)
+    :param hash_options: Extra hash options to be used when installing the install req (likely unused)
+    :param constraint: Whether the requirement is a constraint.
+    :param line_source: The source of the line (e.g. "requirements.txt").
+    :param user_supplied: Whether the requirement was directly provided by the user.
+    :param config_settings: Configuration settings to be used when installing the install req (likely unused)
+    :param expand_env: Whether to expand environment variables in the line. (definitely used)
+    :return: A tuple of the InstallRequirement and the name of the package (if determined).
     """
-    name = name.strip("'")
-    editable = False
-    if name.startswith("-e "):
-        # Editable requirement
-        editable = True
-        name = name.split("-e ")[1]
-    if has_name_with_extras(name):
-        name = name.split(" @ ", 1)[1]
+    name = None
+    pip_line = pip_line.strip("'")
+    for new_req_symbol in ("@ ", " @ "):  # Check for new style pip lines
+        if new_req_symbol in pip_line:
+            pip_line_parts = pip_line.split(new_req_symbol, 1)
+            name = pip_line_parts[0]
+            pip_line = pip_line_parts[1]
+    if pip_line.startswith("-e "):  # Editable requirements
+        pip_line = pip_line.split("-e ")[1]
+        return install_req_from_editable(pip_line, line_source), name
 
     if expand_env:
-        name = expand_env_variables(name)
+        pip_line = expand_env_variables(pip_line)
 
-    if editable or os.path.isdir(name):
-        return install_req_from_editable(name, line_source)
-
-    vcs_part = name
-    if "@ " in name:  # Check for new style vcs lines
-        vcs_part = name.split("@ ", 1)[1]
+    vcs_part = pip_line
     for vcs in VCS_LIST:
         if vcs_part.startswith(f"{vcs}+"):
             link = get_link_from_line(vcs_part)
-            return InstallRequirement(
+            install_req = InstallRequirement(
                 None,
                 comes_from,
                 link=link,
@@ -919,20 +970,23 @@ def expansive_install_req_from_line(
                 constraint=constraint,
                 user_supplied=user_supplied,
             )
-    if urlparse(name).scheme in ("http", "https", "file") or os.path.isfile(name):
-        parts = parse_req_from_line(name, line_source)
+            return install_req, name
+    if urlparse(pip_line).scheme in ("http", "https", "file") or any(
+        pip_line.endswith(s) for s in INSTALLABLE_EXTENSIONS
+    ):
+        parts = parse_req_from_line(pip_line, line_source)
     else:
         # It's a requirement
-        if "--index" in name:
-            name = name.split("--index")[0]
-        if " -i " in name:
-            name = name.split(" -i ")[0]
+        if "--index" in pip_line:
+            pip_line = pip_line.split("--index")[0]
+        if " -i " in pip_line:
+            pip_line = pip_line.split(" -i ")[0]
         # handle local version identifiers (like the ones torch uses in their public index)
-        if "+" in name:
-            name = name.split("+")[0]
-        parts = parse_req_from_line(name, line_source)
+        if "+" in pip_line:
+            pip_line = pip_line.split("+")[0]
+        parts = parse_req_from_line(pip_line, line_source)
 
-    return InstallRequirement(
+    install_req = InstallRequirement(
         parts.requirement,
         comes_from,
         link=parts.link,
@@ -946,9 +1000,36 @@ def expansive_install_req_from_line(
         extras=parts.extras,
         user_supplied=user_supplied,
     )
+    return install_req, name
+
+
+def _file_path_from_pipfile(path_obj, pipfile_entry):
+    """Creates an installable file path from a pipfile entry.
+    Handles local and remote paths, files and directories;
+    supports extras and editable specification.
+    Outputs a pip installable line.
+    """
+    parsed_url = urlparse(str(path_obj))
+    if parsed_url.scheme in ["http", "https", "ftp", "file"]:
+        req_str = str(path_obj)
+    elif path_obj.is_absolute():
+        req_str = str(path_obj.as_posix())
+    else:
+        req_str = f"./{str(path_obj.as_posix())}"
+
+    if pipfile_entry.get("extras"):
+        req_str = f"{req_str}[{','.join(pipfile_entry['extras'])}]"
+    if pipfile_entry.get("editable", False):
+        req_str = f"-e {req_str}"
+
+    return req_str
 
 
 def install_req_from_pipfile(name, pipfile):
+    """Creates an InstallRequirement from a name and a pipfile entry.
+    Handles VCS, local & remote paths, and regular named requirements.
+    "file" and "path" entries are treated the same.
+    """
     _pipfile = {}
     vcs = None
     if hasattr(pipfile, "keys"):
@@ -981,16 +1062,18 @@ def install_req_from_pipfile(name, pipfile):
         req_str = f"{vcs_url}@{_pipfile.get('ref', fallback_ref)}{extras_str}"
         if not req_str.startswith(f"{vcs}+"):
             req_str = f"{vcs}+{req_str}"
-        if f"{vcs}+file://" in req_str:
+        if f"{vcs}+file://" in req_str or _pipfile.get("editable", False):
             req_str = (
                 f"-e {req_str}#egg={name}{extras_str}{subdirectory.replace('#', '&')}"
             )
         else:
             req_str = f"{name}{extras_str}@ {req_str}{subdirectory}"
     elif "path" in _pipfile:
-        req_str = str(Path(_pipfile["path"]).as_posix())
+        path_obj = Path(_pipfile["path"])
+        req_str = _file_path_from_pipfile(path_obj, _pipfile)
     elif "file" in _pipfile:
-        req_str = str(Path(_pipfile["file"]).as_posix())
+        path_obj = Path(_pipfile["file"])
+        req_str = _file_path_from_pipfile(path_obj, _pipfile)
     else:
         # We ensure version contains an operator. Default to equals (==)
         _pipfile["version"] = version = get_version(pipfile)
@@ -1000,7 +1083,7 @@ def install_req_from_pipfile(name, pipfile):
             version = ""
         req_str = f"{name}{extras_str}{version}"
 
-    install_req = expansive_install_req_from_line(
+    install_req, _ = expansive_install_req_from_line(
         req_str,
         comes_from=None,
         use_pep517=False,
