@@ -202,8 +202,11 @@ class Resolver:
             if not dep:
                 continue
             is_constraint = True
-            install_req = expansive_install_req_from_line(dep, expand_env=True)
-            package_name = determine_package_name(install_req)
+            install_req, package_name = expansive_install_req_from_line(
+                dep, expand_env=True
+            )
+            if package_name is None:
+                package_name = determine_package_name(install_req)
             original_deps[package_name] = dep
             install_reqs[package_name] = install_req
             index, extra_index, trust_host, remainder = parse_indexes(dep)
@@ -245,7 +248,6 @@ class Resolver:
                 resolver.skipped[package_name] = dep
         resolver.initial_constraints = constraints
         resolver.index_lookup = index_lookup
-        resolver.finder.index_lookup = index_lookup
         resolver.markers_lookup = markers_lookup
         return resolver
 
@@ -266,7 +268,7 @@ class Resolver:
         pip_args.extend(["--cache-dir", self.project.s.PIPENV_CACHE_DIR])
         return pip_args
 
-    @cached_property
+    @property  # cached_property breaks authenticated private indexes
     def pip_args(self):
         use_pep517 = environments.get_from_env("USE_PEP517", prefix="PIP")
         build_isolation = environments.get_from_env("BUILD_ISOLATION", prefix="PIP")
@@ -298,7 +300,7 @@ class Resolver:
         )
         return default_constraint_filename
 
-    @cached_property
+    @property  # cached_property breaks authenticated private indexes
     def pip_options(self):
         pip_options, _ = self.pip_command.parser.parse_args(self.pip_args)
         pip_options.cache_dir = self.project.s.PIPENV_CACHE_DIR
@@ -335,12 +337,13 @@ class Resolver:
         )
         return finder
 
-    @property
-    def finder(self):
+    def finder(self, ignore_compatibility=False):
         finder = self.package_finder
         index_lookup = self.prepare_index_lookup()
         finder._link_collector.index_lookup = index_lookup
+        finder._link_collector.search_scope.index_restricted = True
         finder._link_collector.search_scope.index_lookup = index_lookup
+        finder._ignore_compatibility = ignore_compatibility
         return finder
 
     @cached_property
@@ -349,7 +352,7 @@ class Resolver:
         pip_options.extra_index_urls = []
         return parse_requirements(
             self.constraint_file,
-            finder=self.finder,
+            finder=self.finder(),
             session=self.session,
             options=pip_options,
         )
@@ -361,7 +364,7 @@ class Resolver:
         parsed_default_constraints = parse_requirements(
             self.default_constraint_file,
             constraint=True,
-            finder=self.finder,
+            finder=self.finder(),
             session=self.session,
             options=pip_options,
         )
@@ -411,7 +414,7 @@ class Resolver:
             globally_managed=True
         ) as directory:
             pip_options = self.pip_options
-            finder = self.finder
+            finder = self.finder()
             wheel_cache = WheelCache(pip_options.cache_dir)
             preparer = self.pip_command.make_requirement_preparer(
                 temp_build_dir=directory,
@@ -447,17 +450,59 @@ class Resolver:
                 self.resolved_tree.update(self.results)
         return self.resolved_tree
 
+    def _get_pipfile_markers(self, pipfile_entry):
+        sys_platform = pipfile_entry.get("sys_platform")
+        platform_machine = pipfile_entry.get("platform_machine")
+        markers = pipfile_entry.get("markers")
+
+        if sys_platform:
+            sys_platform = f"sys_platform {sys_platform}"
+        if platform_machine:
+            platform_machine = f"platform_machine {platform_machine}"
+
+        combined_markers = [
+            f"({marker})"
+            for marker in (sys_platform, markers, platform_machine)
+            if marker
+        ]
+
+        return " and ".join(combined_markers).strip()
+
+    def _fold_markers(self, dependency_tree, install_req):
+        comes_from = dependency_tree[install_req.name]
+
+        if comes_from == "Pipfile":
+            pipfile_entry = self.pipfile_entries.get(install_req.name)
+            if pipfile_entry and isinstance(pipfile_entry, dict):
+                return self._get_pipfile_markers(pipfile_entry)
+        else:
+            markers = self._fold_markers(dependency_tree, comes_from)
+            if markers:
+                self.markers_lookup[install_req.name] = markers
+            return markers
+
     def resolve_constraints(self):
         from .markers import marker_from_specifier
 
+        # Build mapping of where package originates from
+        comes_from = {}
+        for result in self.resolved_tree:
+            if isinstance(result.comes_from, InstallRequirement):
+                comes_from[result.name] = result.comes_from
+            else:
+                comes_from[result.name] = "Pipfile"
+
+        # Build up the results tree with markers
         new_tree = set()
         for result in self.resolved_tree:
             if result.markers:
                 self.markers[result.name] = result.markers
             else:
-                candidate = self.finder.find_best_candidate(
-                    result.name, result.specifier
-                ).best_candidate
+                candidate = (
+                    self.finder()
+                    .find_best_candidate(result.name, result.specifier)
+                    .best_candidate
+                )
                 if candidate:
                     requires_python = candidate.link.requires_python
                     if requires_python:
@@ -475,6 +520,11 @@ class Resolver:
                                 err=True,
                             )
             new_tree.add(result)
+
+        # Fold markers
+        for result in new_tree:
+            self._fold_markers(comes_from, result)
+
         self.resolved_tree = new_tree
 
     def collect_hashes(self, ireq):
@@ -500,9 +550,11 @@ class Resolver:
                 if hashes:
                     return hashes
 
-        applicable_candidates = self.finder.find_best_candidate(
-            ireq.name, ireq.specifier
-        ).iter_applicable()
+        applicable_candidates = (
+            self.finder(ignore_compatibility=True)
+            .find_best_candidate(ireq.name, ireq.specifier)
+            .iter_applicable()
+        )
         applicable_candidates = list(applicable_candidates)
         if applicable_candidates:
             return sorted(
@@ -548,7 +600,7 @@ class Resolver:
         reqs = [(ireq,) for ireq in self.resolved_tree]
         results = {}
         for (ireq,) in reqs:
-            if normalize_name(ireq.name) in self.skipped.keys():
+            if normalize_name(ireq.name) in self.skipped:
                 continue
             collected_hashes = self.hashes.get(ireq, set())
             if collected_hashes:
